
module std.c.windows.dbghelp;


version (Windows)
{
}
else
{
  static assert(0);		// Windows only
}

import std.c.windows.windows;

private {
  import std.stdint;
}


extern (Windows)
{

  /************************************************************
   * The following definitions should probably go elsewhere
   ************************************************************/
//  alias byte    BYTE;
  alias int64_t   DWORD64;
  alias DWORD64*  PDWORD64;
  alias char*     PCHAR;
  alias const char* PCTSTR;
  const int IMAGE_FILE_MACHINE_I386 = 0x014c;  // Intel 386.




  struct _IMAGEHLP_SYMBOL64 {
    DWORD                       SizeOfStruct;           // set to sizeof(IMAGEHLP_SYMBOL64)
    DWORD64                     Address;                // virtual address including dll base address
    DWORD                       Size;                   // estimated size of symbol, can be zero
    DWORD                       Flags;                  // info about the symbols, see the SYMF defines
    DWORD                       MaxNameLength;          // maximum size of symbol name in 'Name'
    CHAR                        Name;                   // symbol name (null terminated string)
  }
  alias _IMAGEHLP_SYMBOL64  IMAGEHLP_SYMBOL64;
  alias _IMAGEHLP_SYMBOL64* PIMAGEHLP_SYMBOL64;

  enum ADDRESS_MODE {
      AddrMode1616,
      AddrMode1632,
      AddrModeReal,
      AddrModeFlat
  }

  struct _tagADDRESS64 {
      DWORD64       Offset;
      WORD          Segment;
      ADDRESS_MODE  Mode;
  }
  alias _tagADDRESS64  ADDRESS64;
  alias _tagADDRESS64* LPADDRESS64;


  //
  // This structure is included in the STACKFRAME structure,
  // and is used to trace through usermode callbacks in a thread's
  // kernel stack.  The values must be copied by the kernel debugger
  // from the DBGKD_GET_VERSION and WAIT_STATE_CHANGE packets.
  //

  //
  // New KDHELP structure for 64 bit system support.
  // This structure is preferred in new code.
  //
  struct _KDHELP64 {
      //
      // address of kernel thread object, as provided in the
      // WAIT_STATE_CHANGE packet.
      //
      DWORD64   Thread;

      //
      // offset in thread object to pointer to the current callback frame
      // in kernel stack.
      //
      DWORD   ThCallbackStack;

      //
      // offset in thread object to pointer to the current callback backing
      // store frame in kernel stack.
      //
      DWORD   ThCallbackBStore;

      //
      // offsets to values in frame:
      //
      // address of next callback frame
      DWORD   NextCallback;

      // address of saved frame pointer (if applicable)
      DWORD   FramePointer;


      //
      // Address of the kernel function that calls out to user mode
      //
      DWORD64   KiCallUserMode;

      //
      // Address of the user mode dispatcher function
      //
      DWORD64   KeUserCallbackDispatcher;

      //
      // Lowest kernel mode address
      //
      DWORD64   SystemRangeStart;

      DWORD64  Reserved[8];

  }
  alias _KDHELP64  KDHELP64;
  alias _KDHELP64* PKDHELP64;


  struct _tagSTACKFRAME64 {
      ADDRESS64   AddrPC;               // program counter
      ADDRESS64   AddrReturn;           // return address
      ADDRESS64   AddrFrame;            // frame pointer
      ADDRESS64   AddrStack;            // stack pointer
      ADDRESS64   AddrBStore;           // backing store pointer
      PVOID       FuncTableEntry;       // pointer to pdata/fpo or NULL
      DWORD64     Params[4];            // possible arguments to the function
      BOOL        Far;                  // WOW far call
      BOOL        Virtual;              // is this a virtual frame?
      DWORD64     Reserved[3];
      KDHELP64    KdHelp;
  }
  alias _tagSTACKFRAME64  STACKFRAME64;
  alias _tagSTACKFRAME64* LPSTACKFRAME64;



  struct _IMAGEHLP_LINE64 {
      DWORD                       SizeOfStruct;           // set to sizeof(IMAGEHLP_LINE64)
      PVOID                       Key;                    // internal
      DWORD                       LineNumber;             // line number in file
      PCHAR                       FileName;               // full filename
      DWORD64                     Address;                // first instruction of line
  } 
  alias _IMAGEHLP_LINE64  IMAGEHLP_LINE64;
  alias _IMAGEHLP_LINE64* PIMAGEHLP_LINE64;



  enum {
    SYMOPT_DEFERRED_LOADS = 0x00000004,
    SYMOPT_LOAD_LINES = 0x00000010,
  }

  DWORD SymSetOptions(DWORD SymOptions);
  BOOL  SymInitialize(HANDLE hProcess, PCTSTR UserSearchPath, BOOL fInvadeProcess);


  alias BOOL function(
      HANDLE hProcess,
      DWORD64 lpBaseAddress,
      PVOID lpBuffer,
      DWORD nSize,
      LPDWORD lpNumberOfBytesRead
  ) PREAD_PROCESS_MEMORY_ROUTINE64;

  alias PVOID function(
      HANDLE hProcess,
      DWORD64 AddrBase
  ) PFUNCTION_TABLE_ACCESS_ROUTINE64;

  alias DWORD64 function (
      HANDLE hProcess,
      DWORD64 Address
  ) PGET_MODULE_BASE_ROUTINE64;

  alias DWORD64 function (
      HANDLE hProcess,
      HANDLE hThread,
      LPADDRESS64 lpaddr
  ) PTRANSLATE_ADDRESS_ROUTINE64;

  BOOL StackWalk64(
                      DWORD                             MachineType,
                      HANDLE                            hProcess,
                      HANDLE                            hThread,
                      LPSTACKFRAME64                    StackFrame,
                      PVOID                             ContextRecord,
                      PREAD_PROCESS_MEMORY_ROUTINE64    ReadMemoryRoutine,
                      PFUNCTION_TABLE_ACCESS_ROUTINE64  FunctionTableAccessRoutine,
                      PGET_MODULE_BASE_ROUTINE64        GetModuleBaseRoutine,
                      PTRANSLATE_ADDRESS_ROUTINE64      TranslateAddress
                      );



  PVOID SymFunctionTableAccess64(HANDLE  hProcess, DWORD64 AddrBase);
  DWORD64 SymGetModuleBase64(HANDLE hProcess, DWORD64 qwAddr);


  BOOL SymGetSymFromAddr64(
    HANDLE              hProcess,
    DWORD64             qwAddr,
    PDWORD64            pdwDisplacement,
    PIMAGEHLP_SYMBOL64  Symbol
    );

  BOOL SymGetLineFromAddr64(
      HANDLE                  hProcess,
      DWORD64                 qwAddr,
      PDWORD                  pdwDisplacement,
      PIMAGEHLP_LINE64        Line64
      );


  BOOL SymCleanup(
      HANDLE hProcess
      );


}


